import React, { useState, useEffect } from 'react';
import ReactDOM from 'react-dom/client';

const PRODUCT_PRICE = 79.99;
const HST_RATE = 0.13;
const SHIPPING_COST = 0; // Services don't have shipping

const e = React.createElement;

const SideMenu = ({ isOpen, onClose, user, onLogin, onLogout, deferredPrompt, onInstall }) => {
    const [email, setEmail] = useState('');
    const [password, setPassword] = useState('');
    const [isLoginFormVisible, setIsLoginFormVisible] = useState(false);
    const [isLoggingIn, setIsLoggingIn] = useState(false);

    const handleLoginClick = () => {
        setIsLoginFormVisible(true);
    };

    const handleLoginSubmit = (e) => {
        e.preventDefault();
        if (!email) return;
        setIsLoggingIn(true);
        setTimeout(() => {
            const name = email.split('@')[0];
            const capitalizedName = name.charAt(0).toUpperCase() + name.slice(1);
            onLogin({ name: capitalizedName, initial: capitalizedName.charAt(0) });
            setIsLoggingIn(false);
            setIsLoginFormVisible(false);
            setEmail('');
            setPassword('');
            setTimeout(onClose, 300);
        }, 1500);
    };
    
    const handleInstallClick = () => {
        if(onInstall) onInstall();
    };

    const handleLogoutClick = () => {
        onLogout();
        onClose();
    };

    const handleBackdropClick = (e) => {
        if (e.target === e.currentTarget) {
            onClose();
        }
    };

    const loginForm = e("form", { className: "login-form", onSubmit: handleLoginSubmit },
        e("h4", null, "Member Login"),
        e("div", { className: "form-group" },
            e("label", { htmlFor: "email" }, "Email"),
            e("input", { type: "email", id: "email", value: email, onChange: ev => setEmail(ev.target.value), placeholder: "your@email.com", required: true })
        ),
        e("div", { className: "form-group" },
            e("label", { htmlFor: "password" }, "Password"),
            e("input", { type: "password", id: "password", value: password, onChange: ev => setPassword(ev.target.value), placeholder: "••••••••", required: true })
        ),
        e("button", { type: "submit", className: "menu-action-btn", disabled: isLoggingIn },
            isLoggingIn ? 'Logging in...' : 'Login'
        )
    );
    
    const bottomActions = e("div", {className: "side-menu-footer"},
        deferredPrompt && e("button", { onClick: handleInstallClick, className: "menu-action-btn install-btn" }, "Install App"),
        user ?
        e("button", { onClick: handleLogoutClick, className: "menu-action-btn logout-btn" }, "Logout") :
        e(React.Fragment, null,
            !isLoginFormVisible && e("button", { onClick: handleLoginClick, className: "menu-action-btn" }, "Login"),
            isLoginFormVisible && loginForm
        )
    );

    return e("div", { className: `side-menu-overlay ${isOpen ? 'open' : ''}`, onClick: handleBackdropClick },
        e("div", { className: `side-menu ${isOpen ? 'open' : ''}` },
            e("div", { className: "side-menu-header" },
                e("h3", null, "Menu"),
                e("button", { onClick: onClose, className: "close-menu-btn", "aria-label": "Close menu" }, "×")
            ),
            e("div", { className: "side-menu-content" },
                e("div", { className: "profile-section" },
                    e("div", { className: "avatar" }, user ? user.initial : 'G'),
                    e("div", { className: "profile-info" },
                        e("h4", null, user ? user.name : 'Guest'),
                        user && e("p", null, "Welcome back!")
                    )
                ),
                e("nav", { className: "menu-nav" },
                    e("a", { href: "#", onClick: onClose }, "Home"),
                    user && e("a", { href: "#", onClick: onClose }, "My Services"),
                    user && e("a", { href: "#", onClick: onClose }, "Settings")
                ),
                bottomActions
            )
        )
    );
};

const CreditCardForm = ({ onSubmit, isProcessing, total }) => {
    const [cardName, setCardName] = useState('');
    const [cardNumber, setCardNumber] = useState('');
    const [expiryDate, setExpiryDate] = useState('');
    const [cvv, setCvv] = useState('');
    const [isFlipped, setIsFlipped] = useState(false);

    const formatCardNumber = (value) => {
        return value.replace(/\s/g, '').replace(/(\d{4})/g, '$1 ').trim();
    };

    const formatExpiryDate = (value) => {
        if (value.length === 2 && expiryDate.length === 1) {
            return value + '/';
        }
        return value;
    };

    return e("form", { className: "payment-form", onSubmit: onSubmit },
        e("h2", null, "Payment Information"),
        e("div", { className: "credit-card-container" },
            e("div", { className: `credit-card ${isFlipped ? 'flipped' : ''}` },
                e("div", { className: "credit-card-front" },
                    e("div", { className: "card-chip" }),
                    e("div", { className: "card-logo" },
                       e("svg", { xmlns: "http://www.w3.org/2000/svg", width: "48", height: "48", viewBox: "0 0 24 24", fill: "#fff" }, 
                           e("path", { d: "M21.16,6.26l-1.44-4.14a.5.5,0,0,0-.48-.32H4.76a.5.5,0,0,0-.48.32L2.84,6.26a.5.5,0,0,0,.08.51l3.52,4.69L2.5,17.23a.5.5,0,0,0,.48,.77h18a.5.5,0,0,0,.48-.77L17.52,11.46l3.52-4.69a.5.5,0,0,0,.12-.51ZM8.58,11.4l-2.4-3.2L7.3,3.8H16.7l1.12,4.4-2.4,3.2Zm7.06,4.32-3.12-4.16,3.12-4.16,1.44,4.16Z" })
                       )
                    ),
                    e("div", { className: "card-number" }, cardNumber || '**** **** **** ****'),
                    e("div", { className: "card-info-row" },
                        e("div", { className: "card-info-item" },
                            e("span", { className: "card-label" }, "Card Holder"),
                            e("span", { className: "card-value" }, cardName.toUpperCase() || 'JOHN DOE')
                        ),
                        e("div", { className: "card-info-item" },
                            e("span", { className: "card-label" }, "Expires"),
                            e("span", { className: "card-value" }, expiryDate || 'MM/YY')
                        )
                    )
                ),
                e("div", { className: "credit-card-back" },
                    e("div", { className: "card-back-stripe" }),
                    e("div", { className: "card-signature-area" },
                        e("span", { className: "card-label" }, "CVV"),
                        e("div", { className: "card-cvv-display" }, cvv)
                    )
                )
            )
        ),
        e("div", { className: "form-group" },
            e("label", { htmlFor: "cardName" }, "Cardholder Name"),
            e("input", { type: "text", id: "cardName", placeholder: "John Doe", required: true, value: cardName, onChange: (ev) => setCardName(ev.target.value) })
        ),
        e("div", { className: "form-group" },
            e("label", { htmlFor: "cardNumber" }, "Card Number"),
            e("input", { type: "text", id: "cardNumber", placeholder: "**** **** **** 1234", required: true, maxLength: 19, value: cardNumber, onChange: (ev) => setCardNumber(formatCardNumber(ev.target.value)) })
        ),
        e("div", { className: "form-row" },
            e("div", { className: "form-group" },
                e("label", { htmlFor: "expiryDate" }, "Expiry Date"),
                e("input", { type: "text", id: "expiryDate", placeholder: "MM/YY", required: true, maxLength: 5, value: expiryDate, onChange: (ev) => setExpiryDate(formatExpiryDate(ev.target.value)) })
            ),
            e("div", { className: "form-group" },
                e("label", { htmlFor: "cvv" }, "CVV"),
                e("input", { type: "text", id: "cvv", placeholder: "123", required: true, maxLength: 3, value: cvv, onChange: (ev) => setCvv(ev.target.value), onFocus: () => setIsFlipped(true), onBlur: () => setIsFlipped(false) })
            )
        ),
        e("div", { className: "secure-payment-info" },
            e("svg", { xmlns: "http://www.w3.org/2000/svg", width: "14", height: "14", viewBox: "0 0 24 24", fill: "none", stroke: "currentColor", strokeWidth: "2", strokeLinecap: "round", strokeLinejoin: "round" },
               e("rect", { x: "3", y: "11", width: "18", height: "11", rx: "2", ry: "2" }),
               e("path", { d: "M7 11V7a5 5 0 0 1 10 0v4" })
            ),
            e("span", null, "Secure 256-bit SSL Encryption")
        ),
        e("button", { type: "submit", className: "pay-button", disabled: isProcessing },
            isProcessing ? 'Processing...' : `Pay $${total.toFixed(2)}`
        )
    );
};

const CheckoutApp = ({ deferredPrompt, onInstallRequest }) => {
    const [quantity, setQuantity] = useState(1);
    const [isProcessing, setIsProcessing] = useState(false);
    const [isMenuOpen, setIsMenuOpen] = useState(false);
    const [user, setUser] = useState(null);
    
    const handleDecrement = () => setQuantity(prev => Math.max(1, prev - 1));
    const handleIncrement = () => setQuantity(prev => prev + 1);

    const handlePaymentSubmit = (e) => {
        e.preventDefault();
        if (isProcessing) return;
        setIsProcessing(true);
        setTimeout(() => {
            setIsProcessing(false);
            alert('Payment successful! Your lawn care service has been booked.');
            setQuantity(1);
        }, 2000);
    };

    const handleLogin = (userData) => setUser(userData);
    const handleLogout = () => setUser(null);

    const subtotal = quantity * PRODUCT_PRICE;
    const hst = subtotal * HST_RATE;
    const total = subtotal + hst + SHIPPING_COST;

    return e(React.Fragment, null,
        e(SideMenu, {
            isOpen: isMenuOpen,
            onClose: () => setIsMenuOpen(false),
            user: user,
            onLogin: handleLogin,
            onLogout: handleLogout,
            deferredPrompt: deferredPrompt,
            onInstall: onInstallRequest
        }),
        e("div", { className: `app-container ${isMenuOpen ? 'menu-open' : ''}` },
            e("header", null,
                e("button", { className: "menu-button", onClick: () => setIsMenuOpen(true), "aria-label": "Open menu" },
                    e("svg", { xmlns: "http://www.w3.org/2000/svg", width: "24", height: "24", viewBox: "0 0 24 24", fill: "none", stroke: "currentColor", strokeWidth: "2.5", strokeLinecap: "round", strokeLinejoin: "round" },
                        e("line", { x1: "3", y1: "12", x2: "21", y2: "12" }),
                        e("line", { x1: "3", y1: "6", x2: "21", y2: "6" }),
                        e("line", { x1: "3", y1: "18", x2: "21", y2: "18" })
                    )
                ),
                e("h1", null, "Checkout")
            ),
            e("main", null,
                e("section", { className: "product-details" },
                    e("img", { src: "https://images.unsplash.com/photo-1455589637845-94f4c04f989f?q=80&w=1932&auto=format&fit=crop", alt: "Freshly Mowed Lawn", className: "product-image" }),
                    e("div", { className: "product-info" },
                        e("h2", null, "Premium Lawn Care"),
                        e("p", { className: "product-price" }, `$${PRODUCT_PRICE.toFixed(2)} / service`),
                        e("div", { className: "quantity-selector" },
                            e("button", { onClick: handleDecrement, "aria-label": "Decrease quantity" }, "-"),
                            e("span", null, 1),
                            e("button", { onClick: handleIncrement, "aria-label": "Increase quantity" }, "+")
                        )
                    )
                ),
                e("section", { className: "order-summary" },
                    e("div", { className: "summary-row" },
                        e("span", null, "Subtotal"),
                        e("span", null, `$${subtotal.toFixed(2)}`)
                    ),
                    e("div", { className: "summary-row" },
                        e("span", null, "HST (13%)"),
                        e("span", null, `$${hst.toFixed(2)}`)
                    ),
                    e("div", { className: "summary-row total-row" },
                        e("span", null, "Total"),
                        e("span", null, `$${total.toFixed(2)}`)
                    )
                ),
                e(CreditCardForm, { onSubmit: handlePaymentSubmit, isProcessing: isProcessing, total: total })
            )
        )
    );
};

const LandingPage = ({ onLaunch, onInstall, canInstall }) => {
    const staticAppPreview = e("div", { className: "app-container" },
        e("header", null,
            e("button", { className: "menu-button", "aria-label": "Open menu" },
                e("svg", { xmlns: "http://www.w3.org/2000/svg", width: "24", height: "24", viewBox: "0 0 24 24", fill: "none", stroke: "currentColor", strokeWidth: "2.5", strokeLinecap: "round", strokeLinejoin: "round" },
                    e("line", { x1: "3", y1: "12", x2: "21", y2: "12" }),
                    e("line", { x1: "3", y1: "6", x2: "21", y2: "6" }),
                    e("line", { x1: "3", y1: "18", x2: "21", y2: "18" })
                )
            ),
            e("h1", null, "Checkout")
        ),
        e("main", null,
            e("section", { className: "product-details" },
                e("img", { src: "https://images.unsplash.com/photo-1455589637845-94f4c04f989f?q=80&w=1932&auto=format&fit=crop", alt: "Freshly Mowed Lawn", className: "product-image" }),
                e("div", { className: "product-info" },
                    e("h2", null, "Premium Lawn Care"),
                    e("p", { className: "product-price" }, `$${PRODUCT_PRICE.toFixed(2)} / service`),
                     e("div", { className: "quantity-selector" },
                        e("button", { "aria-label": "Decrease quantity" }, "-"),
                        e("span", null, 1),
                        e("button", { "aria-label": "Increase quantity" }, "+")
                    )
                )
            )
        )
    );

    return e("div", { className: "landing-page" },
        e("div", { className: "landing-content" },
            e("h1", { className: "landing-title" }, "The Future of Lawn Care is Here"),
            e("p", { className: "landing-subtitle" }, "Manage your lawn care services with a simple, beautiful, and installable web app."),
            e("div", { className: "landing-features" },
                e("div", { className: "feature" }, "✓ Easy Payments"),
                e("div", { className: "feature" }, "✓ Service Management"),
                e("div", { className: "feature" }, "✓ Works Offline")
            )
        ),
        e("div", { className: "iphone-frame" },
            e("div", { className: "iphone-notch" }),
            staticAppPreview
        ),
        e("div", { className: "landing-cta" },
            e("button", { className: "launch-btn", onClick: onLaunch }, "Launch App"),
            canInstall && e("button", { className: "install-btn-landing", onClick: onInstall }, "Add to Home Screen")
        )
    );
};

const App = () => {
    const [isAppLaunched, setIsAppLaunched] = useState(false);
    const [deferredPrompt, setDeferredPrompt] = useState(null);
    const isStandalone = window.matchMedia('(display-mode: standalone)').matches || (window.navigator as any).standalone;

    useEffect(() => {
        const handler = (e) => {
            e.preventDefault();
            setDeferredPrompt(e);
        };
        window.addEventListener('beforeinstallprompt', handler);
        
        if (isStandalone) {
            document.body.classList.add('standalone');
        } else {
            document.body.classList.remove('standalone');
        }

        return () => window.removeEventListener('beforeinstallprompt', handler);
    }, [isStandalone]);

    const handleInstall = async () => {
        if (!deferredPrompt) return;
        deferredPrompt.prompt();
        const { outcome } = await deferredPrompt.userChoice;
        console.log(`User response to the install prompt: ${outcome}`);
        setDeferredPrompt(null);
    };

    if (isStandalone) {
        return e(CheckoutApp, { deferredPrompt: deferredPrompt, onInstallRequest: handleInstall });
    }

    if (isAppLaunched) {
        return e("div", { className: "iphone-frame" },
            e("div", { className: "iphone-notch" }),
            e(CheckoutApp, { deferredPrompt: deferredPrompt, onInstallRequest: handleInstall })
        );
    }

    return e(LandingPage, {
        onLaunch: () => setIsAppLaunched(true),
        onInstall: handleInstall,
        canInstall: !!deferredPrompt
    });
};

const root = ReactDOM.createRoot(document.getElementById('root'));
root.render(e(React.StrictMode, null, e(App)));
